@@ -130,24 +130,48 @@ class SwaggerGenerator(Blueprint):
                             }
                         
                         ## define body form, form-urlencoded, file
+                        all_forms = {
+                            "x-www-form-urlencoded": [],
+                            "multipart/form-data": []
+                        }
                         for content_type, generate_schema in {
                             "form-data": self.generate_body_form_schema,
                             "x-www-form-urlencoded": self.generate_body_form_urlencoded_schema,
                             "multipart/form-data": self.generate_body_file_schema
                         }.items():
-                            body_schemas = generate_schema(ep.rule.replace("/","-"), ep.paired_params)
-                            if body_schemas:
-                                for body_schema in body_schemas:
-                                    if "definitions" in body_schema:
-                                        definitions = body_schema.pop("definitions")
-                                        self.template["components"]["schemas"].update(definitions)
-                                    self.template["paths"][ep.rule][ep.method]["requestBody"] = {
-                                        "content":{
-                                            content_type:{
-                                                "schema": body_schema
-                                            }
-                                        }
-                                    }
+                            body_schemas = generate_schema(ep.rule.replace("/","-"), ep.paired_params)                        
+                            content_type = "multipart/form-data" if content_type == "form-data" else content_type
+                            all_forms[content_type].extend(body_schemas)
+                        
+                        final_form_schema = {
+                            "x-www-form-urlencoded": {
+                                "schema": {
+                                    "title": ep.rule.replace("/","-")+"__form_urlencoded",
+                                    "type": "object",
+                                    "properties": {},
+                                    "required": []
+                                }
+                            },
+                            "multipart/form-data": {
+                                "schema": {
+                                    "title": ep.rule.replace("/","-")+"__form",
+                                    "type": "object",
+                                    "properties": {},
+                                    "required": []
+                                }
+                            }
+                        }
+                        for k, f in all_forms.items():
+                            if f:
+                                for ff in f:
+                                    final_form_schema[k]["schema"]["properties"].update(ff["properties"])
+                                    final_form_schema[k]["schema"]["required"].extend(ff["required"])
+                            else:
+                                final_form_schema.pop(k)
+                        if "requestBody" not in self.template["paths"][ep.rule][ep.method]:
+                            self.template["paths"][ep.rule][ep.method]["requestBody"] = {"content":{}}
+                        self.template["paths"][ep.rule][ep.method]["requestBody"]["content"].update(final_form_schema)
+                        
         if self.additional_path:
             self.template["paths"].update(self.additional_path)
         if self.additional_components:
@@ -220,16 +244,18 @@ class SwaggerGenerator(Blueprint):
             params_type: FormType
         ):
         all_forms = []
+        i = 0
         for k, p in paired_params.items():
             po = p.param_object
             if type(po) == params_type:
                 ss = create_model(
-                    name+"_"+po._type.value,
-                    **{k: (Any, p._default)}
+                    name+"_"+po._type.value+f"-{i}",
+                    **{k: (str, p._default)}
                 )
                 all_forms.append(
                     ss.schema(ref_template="#/components/schemas/{model}")
                 )
+                i += 1
         return all_forms
     
     def generate_body_form_schema(self, name, paired_params):
@@ -245,6 +271,9 @@ class SwaggerGenerator(Blueprint):
                 list(b["properties"].keys())[0]
             ]["format"] = "binary"
         return body_form
+
+    def unite_form_schema(self, name, all_forms):
+        1
     
     def get_schema_dtype(self, dtype):
         schema_data_type = {
